Exception: MissingRequiredOptionException

Inherits:
StandardError
  • Object
show all
Defined in:
lib/exceptions/MissingRequiredOptionException.rb

Overview

www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an “AS IS” BASIS,

WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contact Info: <[email protected]> and <[email protected]>

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(kind) ⇒ MissingRequiredOptionException

Returns a new instance of MissingRequiredOptionException.



25
26
27
28
29
30
31
# File 'lib/exceptions/MissingRequiredOptionException.rb', line 25

def initialize(kind)

  @kind = kind
  msg = "You are missing a required option.  It must be specified on the command line or configuration file: #{kind}"
  super(msg)

end

Instance Attribute Details

#kindObject (readonly)

Returns the value of attribute kind.



24
25
26
# File 'lib/exceptions/MissingRequiredOptionException.rb', line 24

def kind
  @kind
end